==> zio-aws-iot_2.12-5.17.191.2-sources.jar: zio/aws/iot/model/HttpUrlDestinationSummary.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.Url
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class HttpUrlDestinationSummary(
    confirmationUrl: Optional[Url] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary = {
    import HttpUrlDestinationSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
      .builder()
      .optionallyWith(
        confirmationUrl.map(value => Url.unwrap(value): java.lang.String)
      )(_.confirmationUrl)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.HttpUrlDestinationSummary.ReadOnly =
    zio.aws.iot.model.HttpUrlDestinationSummary.wrap(buildAwsValue())
}
object HttpUrlDestinationSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.HttpUrlDestinationSummary =
      zio.aws.iot.model
        .HttpUrlDestinationSummary(confirmationUrl.map(value => value))
    def confirmationUrl: Optional[Url]
    def getConfirmationUrl: ZIO[Any, AwsError, Url] =
      AwsError.unwrapOptionField("confirmationUrl", confirmationUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
  ) extends zio.aws.iot.model.HttpUrlDestinationSummary.ReadOnly {
    override val confirmationUrl: Optional[Url] = zio.aws.core.internal
      .optionalFromNullable(impl.confirmationUrl())
      .map(value => zio.aws.iot.model.primitives.Url(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
  ): zio.aws.iot.model.HttpUrlDestinationSummary.ReadOnly = new Wrapper(impl)
}

==> zio-aws-iot_3-5.17.148.1-sources.jar: zio/aws/iot/model/HttpUrlDestinationSummary.scala <==
package zio.aws.iot.model
import zio.ZIO
import zio.aws.iot.model.primitives.Url
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class HttpUrlDestinationSummary(
    confirmationUrl: Option[Url] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary = {
    import HttpUrlDestinationSummary.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
      .builder()
      .optionallyWith(
        confirmationUrl.map(value => Url.unwrap(value): java.lang.String)
      )(_.confirmationUrl)
      .build()
  }
  def asReadOnly: zio.aws.iot.model.HttpUrlDestinationSummary.ReadOnly =
    zio.aws.iot.model.HttpUrlDestinationSummary.wrap(buildAwsValue())
}
object HttpUrlDestinationSummary {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iot.model.HttpUrlDestinationSummary =
      zio.aws.iot.model
        .HttpUrlDestinationSummary(confirmationUrl.map(value => value))
    def confirmationUrl: Option[Url]
    def getConfirmationUrl: ZIO[Any, AwsError, Url] =
      AwsError.unwrapOptionField("confirmationUrl", confirmationUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
  ) extends zio.aws.iot.model.HttpUrlDestinationSummary.ReadOnly {
    override val confirmationUrl: Option[Url] = scala
      .Option(impl.confirmationUrl())
      .map(value => zio.aws.iot.model.primitives.Url(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iot.model.HttpUrlDestinationSummary
  ): zio.aws.iot.model.HttpUrlDestinationSummary.ReadOnly = new Wrapper(impl)
}
